# Change Log

All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).


## [v1.0.4](https://github.com/oscarmcm/django-places/tree/v1.0.3) (2016-07-20)
[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.3...v1.0.4)

**Fixed bugs:**

- Use Django admin jQuery

## [v1.0.3](https://github.com/oscarmcm/django-places/tree/v1.0.3) (2016-06-01)
[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.2...v1.0.3)

**Fixed bugs:**

- i18n support [\#3](https://github.com/oscarmcm/django-places/issues/3)

## [v1.0.2](https://github.com/oscarmcm/django-places/tree/v1.0.2) (2016-05-12)
[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.1...v1.0.2)

## [v1.0.1](https://github.com/oscarmcm/django-places/tree/v1.0.1) (2016-05-12)
[Full Changelog](https://github.com/oscarmcm/django-places/compare/v1.0.0...v1.0.1)

**Fixed bugs:**

- Geocomplete is not a function [\#1](https://github.com/oscarmcm/django-places/issues/1)

**Merged pull requests:**

- Fixes \#1 Geocomplete is not a function [\#2](https://github.com/oscarmcm/django-places/pull/2) ([oscarmcm](https://github.com/oscarmcm))

## [v1.0.0](https://github.com/oscarmcm/django-places/tree/v1.0.0) (2016-04-28)
